pub struct CommonModel {
pub id: Id,
pub name: String,
pub fields: Vec<Field>,
pub sample: Value,
pub primary: bool,
pub category: String,
pub interface: HashMap<Lang, String>,
pub record_metadata: RecordMetadata,
}Fields
id: Idname: Stringfields: Vec<Field>sample: Valueprimary: boolcategory: Stringinterface: HashMap<Lang, String>record_metadata: RecordMetadataImplementations
Sourceimpl CommonModel
impl CommonModel
pub fn new( name: String, version: Version, fields: Vec<Field>, category: String, sample: Value, primary: bool, interface: HashMap<Lang, String>, ) -> Self
pub fn new_empty() -> Self
pub fn reference(&self) -> Schema
Sourcepub fn generate_as(&self, lang: &Lang) -> String
pub fn generate_as(&self, lang: &Lang) -> String
Generates the model as a string in the specified language without recursively expanding inner models and enums. Simply provides a reference to the inner model or enum.
Arguments
lang- The language to generate the model in
Sourcepub async fn generate_as_expanded<'a>(
&self,
lang: &Lang,
cm_store: &MongoStore<CommonModel>,
ce_store: &MongoStore<CommonEnum>,
strategy: TypeGenerationStrategy<'a>,
) -> String
pub async fn generate_as_expanded<'a>( &self, lang: &Lang, cm_store: &MongoStore<CommonModel>, ce_store: &MongoStore<CommonEnum>, strategy: TypeGenerationStrategy<'a>, ) -> String
Generates the model as a string in the specified language with recursively expanded inner models and enums. This is useful for generating the entire model and its dependencies in a single file.
Arguments
lang- The language to generate the model incm_store- The store for common modelsce_store- The store for common enumsstrategy- The strategy to use for generating the type
pub async fn as_typescript_schema_expanded( &self, cm_store: &MongoStore<CommonModel>, ce_store: &MongoStore<CommonEnum>, type: SchemaType, ) -> String
pub fn request_body(&self, required: bool) -> RequestBody
pub fn get_expandable_fields(&self) -> Vec<Field>
pub fn get_primitive_fields(&self) -> Vec<Field>
pub fn get_enum_references(&self) -> Vec<Field>
pub fn get_enum_fields(&self) -> Vec<Field>
pub fn flatten(self) -> Vec<CommonModel>
pub async fn expand_all( &self, cm_store: MongoStore<CommonModel>, ce_store: MongoStore<CommonEnum>, ) -> Result<Self, IntegrationOSError>
Sourcepub async fn fetch_all_enum_references(
&self,
cm_store: MongoStore<CommonModel>,
ce_store: MongoStore<CommonEnum>,
) -> Result<Vec<CommonEnum>, IntegrationOSError>
pub async fn fetch_all_enum_references( &self, cm_store: MongoStore<CommonModel>, ce_store: MongoStore<CommonEnum>, ) -> Result<Vec<CommonEnum>, IntegrationOSError>
Sourcepub async fn fetch_all_children_common_models(
&self,
store: MongoStore<CommonModel>,
) -> Result<(HashMap<String, CommonModel>, HashSet<String>), IntegrationOSError>
pub async fn fetch_all_children_common_models( &self, store: MongoStore<CommonModel>, ) -> Result<(HashMap<String, CommonModel>, HashSet<String>), IntegrationOSError>
Fetches all the children of the current model and returns two values:
- A map of the children models with their names as keys
- A set of the names of the children models that were not found
pub async fn get_all_common_models( store: MongoStore<CommonModel>, ) -> Result<Vec<String>, IntegrationOSError>
pub fn to_flat_json(&self) -> Value